==> ejc-production-impl-3.0.0-20220610.134712-133-sources.jar: com/ejianc/business/production/bean/ProductiontaskEntity.java <==
package com.ejianc.business.production.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 生产任务单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_production_task")
public class ProductiontaskEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="code")
    private String code; // 订单号
    @TableField(value="sale_order_id")
    private Long saleOrderId; // 销售订单id
    @TableField(value="product_task_from")
    private Integer productTaskFrom; // 生产任务单来源
    @TableField(value="customer_manage_id")
    private Long customerManageId; // 客户管理档案id
    @TableField(value="customer_manage_name")
    private String customerManageName; // 客户管理档案名称
    @TableField(value="project_id")
    private Long projectId; // 工程id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地id
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="order_name")
    private String orderName; // 定料人
    @TableField(value="order_mobile")
    private String orderMobile; // 联系电话
    @TableField(value="project_totle")
    private BigDecimal projectTotle; // 工程总数量
    @TableField(value="ordered_quantity")
    private BigDecimal orderedQuantity; // 已下数量
    @TableField(value="ordered_not")
    private BigDecimal orderedNot; // 待下数量
    @TableField(value="this_quantity")
    private BigDecimal thisQuantity; // 本次数量
    @TableField(value="counting_method")
    private Integer countingMethod; // 计数方法
    @TableField(value="task_time")
    private Date taskTime; // 任务单日期
    @TableField(value="distance")
    private BigDecimal distance; // 距离
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="transport_method")
    private String transportMethod; // 运输方式
    @TableField(value="unit_id")
    private Long unitId; // 机组id
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="team_id")
    private Long teamId; // 班组id
    @TableField(value="team_name")
    private String teamName; // 班组名称
    @TableField(value="product_id")
    private Long productId; // 产品id
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="mix_version_id")
    private Long mixVersionId; // 配比版本主键
    @TableField(value="hot_material_id")
    private Long hotMaterialId; // 热料配比主键
    @TableField(value="operator_id")
    private Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="contract_id")
    private Long contractId; // 销售合同id
    @TableField(value="task_status")
    private Integer taskStatus; // 任务单状态：1 已创建 2 已分配 3 已关闭
    @TableField(value="car_code")
    private String carCode; // 车号
    @TableField(value="region_id")
    private Long regionId; // 区域id
    @TableField(value="region_name")
    private String regionName; // 区域名称
    @TableField(value="asphalt_spec")
    private String asphaltSpec; // 沥青规格
    @TableField(value="add_count")
    private String addCount; // 外加剂用量
    @TableField(value="transport_route")
    private String transportRoute; // 行车路线
    @TableField(value="added_count")
    private String addedCount; // 追加数量
    @TableField(value="distribute_count")
    private BigDecimal distributeCount; // 分配数量
    @TableField(value="afteradd_count")
    private BigDecimal afteraddCount; // 追加后数量数量
    @TableField(value="is_distribute_car")
    private Integer isDistributeCar; // 是否分配车辆 0 否 1 是
    @TableField(value="print_customer_name")
    private String printCustomerName; // 打印客户名称
    @TableField(value="print_product_name")
    private String printProductName; // 打印产品名称
    @TableField(value="print_worksite_name")
    private String printWorksiteName; // 打印工地名称
    @TableField(value="print_supply_name")
    private String printSupplyName; // 打印供应商名称
    @TableField(value="not_distribute_count")
    private BigDecimal notDistributeCount; // 未分配数量

    @TableField(exist=false)
    @SubEntity(serviceName="productiontasktransportService",pidName = "taskId")
    private List<ProductiontasktransportEntity> taskTransportList = new ArrayList<>(); // 运费维护子表

    @TableField(exist=false)
    @SubEntity(serviceName="productiontaskdetailService",pidName = "mid")
    private List<ProductiontaskdetailEntity> productiontaskdetailEntities = new ArrayList<>(); // 外加剂子表



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getSaleOrderId() {
        return saleOrderId;
    }

    public void setSaleOrderId(Long saleOrderId) {
        this.saleOrderId = saleOrderId;
    }
    public Integer getProductTaskFrom() {
        return productTaskFrom;
    }

    public void setProductTaskFrom(Integer productTaskFrom) {
        this.productTaskFrom = productTaskFrom;
    }
    public Long getCustomerManageId() {
        return customerManageId;
    }

    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }
    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }
    public String getOrderMobile() {
        return orderMobile;
    }

    public void setOrderMobile(String orderMobile) {
        this.orderMobile = orderMobile;
    }
    public BigDecimal getProjectTotle() {
        return projectTotle;
    }

    public void setProjectTotle(BigDecimal projectTotle) {
        this.projectTotle = projectTotle;
    }
    public BigDecimal getOrderedQuantity() {
        return orderedQuantity;
    }

    public void setOrderedQuantity(BigDecimal orderedQuantity) {
        this.orderedQuantity = orderedQuantity;
    }
    public BigDecimal getOrderedNot() {
        return orderedNot;
    }

    public void setOrderedNot(BigDecimal orderedNot) {
        this.orderedNot = orderedNot;
    }
    public BigDecimal getThisQuantity() {
        return thisQuantity;
    }

    public void setThisQuantity(BigDecimal thisQuantity) {
        this.thisQuantity = thisQuantity;
    }
    public Integer getCountingMethod() {
        return countingMethod;
    }

    public void setCountingMethod(Integer countingMethod) {
        this.countingMethod = countingMethod;
    }
    public Date getTaskTime() {
        return taskTime;
    }

    public void setTaskTime(Date taskTime) {
        this.taskTime = taskTime;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getTransportMethod() {
        return transportMethod;
    }

    public void setTransportMethod(String transportMethod) {
        this.transportMethod = transportMethod;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getTeamId() {
        return teamId;
    }

    public void setTeamId(Long teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Long getMixVersionId() {
        return mixVersionId;
    }

    public void setMixVersionId(Long mixVersionId) {
        this.mixVersionId = mixVersionId;
    }
    public Long getHotMaterialId() {
        return hotMaterialId;
    }

    public void setHotMaterialId(Long hotMaterialId) {
        this.hotMaterialId = hotMaterialId;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getCarCode() {
        return carCode;
    }

    public void setCarCode(String carCode) {
        this.carCode = carCode;
    }

    public Integer getTaskStatus() {
        return taskStatus;
    }

    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }

    public Long getRegionId() {
        return regionId;
    }

    public void setRegionId(Long regionId) {
        this.regionId = regionId;
    }

    public String getRegionName() {
        return regionName;
    }

    public void setRegionName(String regionName) {
        this.regionName = regionName;
    }

    public String getAsphaltSpec() {
        return asphaltSpec;
    }

    public void setAsphaltSpec(String asphaltSpec) {
        this.asphaltSpec = asphaltSpec;
    }

    public String getAddCount() {
        return addCount;
    }

    public void setAddCount(String addCount) {
        this.addCount = addCount;
    }

    public String getTransportRoute() {
        return transportRoute;
    }

    public void setTransportRoute(String transportRoute) {
        this.transportRoute = transportRoute;
    }

    public List<ProductiontasktransportEntity> getTaskTransportList() {
        return taskTransportList;
    }

    public void setTaskTransportList(List<ProductiontasktransportEntity> taskTransportList) {
        this.taskTransportList = taskTransportList;
    }

    public BigDecimal getDistributeCount() {
        return distributeCount;
    }

    public void setDistributeCount(BigDecimal distributeCount) {
        this.distributeCount = distributeCount;
    }

    public String getAddedCount() {
        return addedCount;
    }

    public void setAddedCount(String addedCount) {
        this.addedCount = addedCount;
    }

    public BigDecimal getAfteraddCount() {
        return afteraddCount;
    }

    public void setAfteraddCount(BigDecimal afteraddCount) {
        this.afteraddCount = afteraddCount;
    }

    public List<ProductiontaskdetailEntity> getProductiontaskdetailEntities() {
        return productiontaskdetailEntities;
    }

    public void setProductiontaskdetailEntities(List<ProductiontaskdetailEntity> productiontaskdetailEntities) {
        this.productiontaskdetailEntities = productiontaskdetailEntities;
    }

    public Integer getIsDistributeCar() {
        return isDistributeCar;
    }

    public void setIsDistributeCar(Integer isDistributeCar) {
        this.isDistributeCar = isDistributeCar;
    }

    public String getPrintCustomerName() {
        return printCustomerName;
    }

    public void setPrintCustomerName(String printCustomerName) {
        this.printCustomerName = printCustomerName;
    }

    public String getPrintProductName() {
        return printProductName;
    }

    public void setPrintProductName(String printProductName) {
        this.printProductName = printProductName;
    }

    public String getPrintWorksiteName() {
        return printWorksiteName;
    }

    public void setPrintWorksiteName(String printWorksiteName) {
        this.printWorksiteName = printWorksiteName;
    }

    public String getPrintSupplyName() {
        return printSupplyName;
    }

    public void setPrintSupplyName(String printSupplyName) {
        this.printSupplyName = printSupplyName;
    }

    public BigDecimal getNotDistributeCount() {
        return notDistributeCount;
    }

    public void setNotDistributeCount(BigDecimal notDistributeCount) {
        this.notDistributeCount = notDistributeCount;
    }
}

==> ejc-production-impl-3.0.0-20220615.135539-150-sources.jar: com/ejianc/business/production/bean/ProductiontaskEntity.java <==
package com.ejianc.business.production.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 生产任务单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_production_task")
public class ProductiontaskEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="code")
    private String code; // 订单号
    @TableField(value="sale_order_id")
    private Long saleOrderId; // 销售订单id
    @TableField(value="product_task_from")
    private Integer productTaskFrom; // 生产任务单来源
    @TableField(value="customer_manage_id")
    private Long customerManageId; // 客户管理档案id
    @TableField(value="customer_manage_name")
    private String customerManageName; // 客户管理档案名称
    @TableField(value="project_id")
    private Long projectId; // 工程id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地id
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="order_name")
    private String orderName; // 定料人
    @TableField(value="order_mobile")
    private String orderMobile; // 联系电话
    @TableField(value="project_totle")
    private BigDecimal projectTotle; // 工程总数量
    @TableField(value="ordered_quantity")
    private BigDecimal orderedQuantity; // 已下数量
    @TableField(value="ordered_not")
    private BigDecimal orderedNot; // 待下数量
    @TableField(value="this_quantity")
    private BigDecimal thisQuantity; // 本次数量
    @TableField(value="counting_method")
    private Integer countingMethod; // 计数方法
    @TableField(value="task_time")
    private Date taskTime; // 任务单日期
    @TableField(value="distance")
    private BigDecimal distance; // 距离
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="transport_method")
    private String transportMethod; // 运输方式
    @TableField(value="unit_id")
    private Long unitId; // 机组id
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="team_id")
    private Long teamId; // 班组id
    @TableField(value="team_name")
    private String teamName; // 班组名称
    @TableField(value="product_id")
    private Long productId; // 产品id
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="mix_version_id")
    private Long mixVersionId; // 配比版本主键
    @TableField(value="hot_material_id")
    private Long hotMaterialId; // 热料配比主键
    @TableField(value="operator_id")
    private Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="contract_id")
    private Long contractId; // 销售合同id
    @TableField(value="task_status")
    private Integer taskStatus; // 任务单状态：1 已创建 2 已分配 3 已关闭
    @TableField(value="car_code")
    private String carCode; // 车号
    @TableField(value="region_id")
    private Long regionId; // 区域id
    @TableField(value="region_name")
    private String regionName; // 区域名称
    @TableField(value="asphalt_spec")
    private String asphaltSpec; // 沥青规格
    @TableField(value="add_count")
    private String addCount; // 外加剂用量
    @TableField(value="transport_route")
    private String transportRoute; // 行车路线
    @TableField(value="added_count")
    private String addedCount; // 追加数量
    @TableField(value="distribute_count")
    private BigDecimal distributeCount; // 分配数量
    @TableField(value="afteradd_count")
    private BigDecimal afteraddCount; // 追加后数量数量
    @TableField(value="is_distribute_car")
    private Integer isDistributeCar; // 是否分配车辆 0 否 1 是
    @TableField(value="print_customer_name")
    private String printCustomerName; // 打印客户名称
    @TableField(value="print_product_name")
    private String printProductName; // 打印产品名称
    @TableField(value="print_worksite_name")
    private String printWorksiteName; // 打印工地名称
    @TableField(value="print_supply_name")
    private String printSupplyName; // 打印供应商名称
    @TableField(value="not_distribute_count")
    private BigDecimal notDistributeCount; // 未分配数量
    @TableField(value="old_task_code")
    private String oldTaskCode; // 打印供应商名称



    @TableField(exist=false)
    @SubEntity(serviceName="productiontaskdetailService",pidName = "mid")
    private List<ProductiontaskdetailEntity> productiontaskdetailEntities = new ArrayList<>(); // 外加剂子表



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getSaleOrderId() {
        return saleOrderId;
    }

    public void setSaleOrderId(Long saleOrderId) {
        this.saleOrderId = saleOrderId;
    }
    public Integer getProductTaskFrom() {
        return productTaskFrom;
    }

    public void setProductTaskFrom(Integer productTaskFrom) {
        this.productTaskFrom = productTaskFrom;
    }
    public Long getCustomerManageId() {
        return customerManageId;
    }

    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }
    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }
    public String getOrderMobile() {
        return orderMobile;
    }

    public void setOrderMobile(String orderMobile) {
        this.orderMobile = orderMobile;
    }
    public BigDecimal getProjectTotle() {
        return projectTotle;
    }

    public void setProjectTotle(BigDecimal projectTotle) {
        this.projectTotle = projectTotle;
    }
    public BigDecimal getOrderedQuantity() {
        return orderedQuantity;
    }

    public void setOrderedQuantity(BigDecimal orderedQuantity) {
        this.orderedQuantity = orderedQuantity;
    }
    public BigDecimal getOrderedNot() {
        return orderedNot;
    }

    public void setOrderedNot(BigDecimal orderedNot) {
        this.orderedNot = orderedNot;
    }
    public BigDecimal getThisQuantity() {
        return thisQuantity;
    }

    public void setThisQuantity(BigDecimal thisQuantity) {
        this.thisQuantity = thisQuantity;
    }
    public Integer getCountingMethod() {
        return countingMethod;
    }

    public void setCountingMethod(Integer countingMethod) {
        this.countingMethod = countingMethod;
    }
    public Date getTaskTime() {
        return taskTime;
    }

    public void setTaskTime(Date taskTime) {
        this.taskTime = taskTime;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getTransportMethod() {
        return transportMethod;
    }

    public void setTransportMethod(String transportMethod) {
        this.transportMethod = transportMethod;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getTeamId() {
        return teamId;
    }

    public void setTeamId(Long teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Long getMixVersionId() {
        return mixVersionId;
    }

    public void setMixVersionId(Long mixVersionId) {
        this.mixVersionId = mixVersionId;
    }
    public Long getHotMaterialId() {
        return hotMaterialId;
    }

    public void setHotMaterialId(Long hotMaterialId) {
        this.hotMaterialId = hotMaterialId;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getCarCode() {
        return carCode;
    }

    public void setCarCode(String carCode) {
        this.carCode = carCode;
    }

    public Integer getTaskStatus() {
        return taskStatus;
    }

    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }

    public Long getRegionId() {
        return regionId;
    }

    public void setRegionId(Long regionId) {
        this.regionId = regionId;
    }

    public String getRegionName() {
        return regionName;
    }

    public void setRegionName(String regionName) {
        this.regionName = regionName;
    }

    public String getAsphaltSpec() {
        return asphaltSpec;
    }

    public void setAsphaltSpec(String asphaltSpec) {
        this.asphaltSpec = asphaltSpec;
    }

    public String getAddCount() {
        return addCount;
    }

    public void setAddCount(String addCount) {
        this.addCount = addCount;
    }

    public String getTransportRoute() {
        return transportRoute;
    }

    public void setTransportRoute(String transportRoute) {
        this.transportRoute = transportRoute;
    }

    public BigDecimal getDistributeCount() {
        return distributeCount;
    }

    public void setDistributeCount(BigDecimal distributeCount) {
        this.distributeCount = distributeCount;
    }

    public String getAddedCount() {
        return addedCount;
    }

    public void setAddedCount(String addedCount) {
        this.addedCount = addedCount;
    }

    public BigDecimal getAfteraddCount() {
        return afteraddCount;
    }

    public void setAfteraddCount(BigDecimal afteraddCount) {
        this.afteraddCount = afteraddCount;
    }

    public List<ProductiontaskdetailEntity> getProductiontaskdetailEntities() {
        return productiontaskdetailEntities;
    }

    public void setProductiontaskdetailEntities(List<ProductiontaskdetailEntity> productiontaskdetailEntities) {
        this.productiontaskdetailEntities = productiontaskdetailEntities;
    }

    public Integer getIsDistributeCar() {
        return isDistributeCar;
    }

    public void setIsDistributeCar(Integer isDistributeCar) {
        this.isDistributeCar = isDistributeCar;
    }

    public String getPrintCustomerName() {
        return printCustomerName;
    }

    public void setPrintCustomerName(String printCustomerName) {
        this.printCustomerName = printCustomerName;
    }

    public String getPrintProductName() {
        return printProductName;
    }

    public void setPrintProductName(String printProductName) {
        this.printProductName = printProductName;
    }

    public String getPrintWorksiteName() {
        return printWorksiteName;
    }

    public void setPrintWorksiteName(String printWorksiteName) {
        this.printWorksiteName = printWorksiteName;
    }

    public String getPrintSupplyName() {
        return printSupplyName;
    }

    public void setPrintSupplyName(String printSupplyName) {
        this.printSupplyName = printSupplyName;
    }

    public BigDecimal getNotDistributeCount() {
        return notDistributeCount;
    }

    public void setNotDistributeCount(BigDecimal notDistributeCount) {
        this.notDistributeCount = notDistributeCount;
    }

    public String getOldTaskCode() {
        return oldTaskCode;
    }

    public void setOldTaskCode(String oldTaskCode) {
        this.oldTaskCode = oldTaskCode;
    }
}
